jiffybox
========

A wrapper around the API of JiffyBox (http://jiffybox.de)
Consisting of a :ref:`python library <api>`
and a :ref:`command line program <cli>` using the library.

Current features
----------------

* Access to the basic API elements

Planned features
----------------

* Implement the whole API
* Use metaclasses instead of ugly hacks in ``__init__()``
* Make string version of objects less ugly
* Tests

Note
----

.. WARNING::
  This library is in **no** way affiliated with domainFACTORY, the provider of the
  JiffyBox service.

License
-------

GPL3
